Summary: Tools for configuring the console (keyboard, virtual terminals, etc.)
Name: kbd
Version: 1.06
Release: 26
License: GPL
Group: System Environment/Base
Source0: ftp://ftp.kernel.org/pub/linux/utils/kbd/kbd-%{version}.tar.bz2
Source1: kbdrate.apps
Source2: kbdrate.pam
Source3: keytable.init
Source4: kbd-update-cyr.tar.bz2
Source5: kbd-latsun-fonts.tar.bz2
Requires: pam >= 0.66-4, /etc/pam.d/system-auth, usermode
BuildRoot: %{_tmppath}/%{name}-root
Patch: kbd-1.05-sparc.patch
Patch1: kbd-1.06-compose.patch
Patch2: kbd-1.0.6-cflags.patch
Patch3: kbd-1.06-nonroot.patch
Patch4: kbd-1.06-othervt.patch
Patch5: kbd-speakup.patch
Obsoletes: console-tools
Provides: console-tools
Conflicts: util-linux < 2.11r-9
Prereq: sed mktemp initscripts >= 5.86-1

%description
The %{name} package contains tools for managing a Linux
system's console's behavior, including the keyboard, the screen
fonts, the virtual terminals and font files.

%prep

%setup -q -a 4 -a 5
%patch -p1 -b .p0
%patch1 -p1 -b .p1
%patch2 -p1 -b .p2
%patch3 -p1 -b .p3
%patch4 -p1 -b .p4
%patch5 -p0

# Default to latarcyrheb-sun16 font for unicode
perl -pi -e 's/LatArCyrHeb-16/latarcyrheb-sun16/' src/unicode_start

%build
export OLD_PO_FILE_INPUT=yes

# We don't want the backups to show up on an actually installed system
# (But we want them after an rpm -bp kbd.spec, so don't remove -b)
find . -name "*.p[0-9]" |xargs rm -f

unset LINGUAS || :

# we don't use % {configure} because the ./configure included here does not
# understand most of the options
CFLAGS="$RPM_OPT_FLAGS" ./configure --datadir=/lib/kbd \
  --mandir=%{_mandir}

cd src
make

%install
rm -rf ${RPM_BUILD_ROOT}

make install DESTDIR=${RPM_BUILD_ROOT}
for binary in setfont dumpkeys kbd_mode unicode_start unicode_stop ; do
  mv $RPM_BUILD_ROOT%{_bindir}/$binary $RPM_BUILD_ROOT/bin
done

# Add init scripts
install -d -m 755 $RPM_BUILD_ROOT/etc/rc.d/init.d
install -m 755 %{SOURCE3} $RPM_BUILD_ROOT/etc/rc.d/init.d/keytable

mkdir -p $RPM_BUILD_ROOT%{_sbindir} $RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
mv $RPM_BUILD_ROOT%{_bindir}/kbdrate $RPM_BUILD_ROOT%{_sbindir}
ln -s consolehelper $RPM_BUILD_ROOT%{_bindir}/kbdrate
install -c -m644 %SOURCE1 $RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps/kbdrate
install -c -m644 %SOURCE2 $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/kbdrate

%find_lang %{name}

%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

%post
/sbin/ldconfig
/sbin/chkconfig --add keytable

%preun
if [ $1 = 0 ]; then
   /sbin/chkconfig --del keytable
fi

%postun -p /sbin/ldconfig

%triggerpostun -- kbd < 1.05-2
/sbin/chkconfig --add keytable

%triggerpostun -- console-tools
/sbin/chkconfig --add keytable

%files -f %{name}.lang
%defattr(-,root,root)
/bin/*
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/*/*
/lib/kbd
%config /etc/rc.d/init.d/keytable
%config %{_sysconfdir}/security/console.apps/*
%config %{_sysconfdir}/pam.d/*

%changelog
* Wed Sep  4 2002 Bill Nottingham <notting@redhat.com> 1.06-26
- don't munge /etc/sysconfig/i18n

* Tue Sep  3 2002 Bill Nottingham <notting@redhat.com> 1.06-25
- don't run setsysfont in upgrade trigger on console-tools

* Thu Aug 29 2002 Jakub Jelinek <jakub@redhat.com> 1.06-24
- use cyr-sun16 cyrillic chars in latarcyrheb-sun16 font
  instead of old LatArCyrHeb-16 chars
- add Euro character to latarcyrheb-sun16
- use latarcyrheb-sun16 by default in unicode_start script

* Tue Aug 27 2002 Jakub Jelinek <jakub@redhat.com> 1.06-23
- add back lat[02]-sun16 fonts plus latarcyrheb-sun16 font

* Thu Aug 22 2002 Karsten Hopp <karsten@redhat.de>
- needs to conflict with older util-linux packages 
  (kbdrate moved between packages)

* Tue Aug 13 2002 Bill Nottingham <notting@redhat.com> 1.06-21
- remove Evil Hack in favor of slightly-less-evil-hack in initscripts

* Tue Jul  9 2002 Bill Nottingham <notting@redhat.com> 1.06-20
- fix speakup keymap names

* Tue Jul 09 2002 Phil Knirsch <pknirsch@redhat.com> 1.06-19
- Evil hack to make setfont work correctly on all consoles (#68018)

* Thu Jun 27 2002 Bill Nottingham <notting@redhat.com> 1.06-18
- move unicode_stop to /bin too
- fix path to loadkeys in keytable.init
- add in speakup keymaps

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Tue Jun 11 2002 Nalin Dahyabhai <nalin@redhat.com> 1.06-16
- fix incorrect path in console.apps configuration file

* Thu May 30 2002 Bill Nottingham <notting@redhat.com> 1.06-14
- move some more stuff to /bin (unicode_start and dependencies)

* Thu May 23 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Mon Feb 25 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-12
- Rebuild in new environment

* Wed Jan 30 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-11
- Oops, actually list the pam files in %files

* Tue Jan 29 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-10
- Add and consolehelper'ify kbdrate

* Tue Jan 29 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-9
- Re-remove kbdrate

* Thu Jan 24 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-7
- Fix build in current environment
- Get rid of kbdrate, it's in util-linux these days

* Wed Jul 18 2001 Matt Wilson <msw@redhat.com>
- added a patch (Patch4) that allows --tty= in setfont
- modified patch not to break translations

* Tue Jul  3 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-4
- Add cyrillic patches from leon@geon.donetsk.ua (#47144)

* Tue Jun 26 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-3
- Fix "Alt+AltGr=Compose" in qwertz-keyboards

* Mon Jun 25 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.06-2
- Fix "make install" and init script (#45327)

* Sat Jun 16 2001 Than Ngo <than@redhat.com>
- update to 1.0.6
- use %%{_tmppath}
- use find_lang
- support new gettext
- remove some patch files, which are included in 1.0.6
- fix to use RPM_OPT_FLAGS

* Thu May  3 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.05-3
- Fix up resizecons

* Wed May  2 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.05-2
- Build everything, obsoletes console-tools
- s/Copyright:/License:/
- License is GPL, not just distributable
- Add our compose mappings from old console-tools
- Add triggerpostun -- console-tools magic to get sane fonts and mappings

* Tue Apr 17 2001 Erik Troan <ewt@redhat.com>
- initial packaging for kbdrate
